# -*- coding: utf-8 -*-
# Copyright (c) 2013 gocept gmbh & co. kg
# See also LICENSE.txt

import fanstatic


MINIFIERS = {'.js': 'jsmin'}


library = fanstatic.Library(
    'gocept.jsform.tests', 'resources', minifiers=MINIFIERS)

jasmine_css = fanstatic.Resource(library, 'jasmine.css')

jasmine_js = fanstatic.Resource(
    library, 'jasmine.js', depends=[jasmine_css])

jasmine = fanstatic.Resource(library, 'jasmine-html.js', depends=[jasmine_js])

setup = fanstatic.Resource(
    library, 'setup_jasmine.js', depends=[jasmine], bottom=False)

integration = fanstatic.Resource(library, 'integration.js', depends=[setup])



# -*- coding: utf-8 -*-
# Copyright (c) 2013 gocept gmbh & co. kg
# See also LICENSE.txt

import fanstatic
import gocept.jasmine.jasmine
import gocept.jasmine.resource
import gocept.jsform
import os


library = fanstatic.Library('gocept.jsform.tests', 'resources')
integration_test = fanstatic.Resource(
    library, 'integration.js', depends=[gocept.jasmine.resource.jasmine])


# Register this library programmatically to avoid making the package metadata
# depend on test-only dependencies.
fanstatic.get_library_registry().add(library)


class JSFormApp(gocept.jasmine.jasmine.TestApp):

    def need_resources(self):
        gocept.jsform.jsform.need()
        integration_test.need()

    @property
    def body(self):
        return '<div id="my_form"></div>'


class JSFormTestCase(gocept.jasmine.jasmine.TestCase):

    layer = gocept.jasmine.jasmine.get_layer(JSFormApp())
    debug = os.environ.get('JASMINE_DEBUG', False)

    def test_integration(self):
        self.run_jasmine()



import fanstatic
import js.classy
import js.jquery
import js.handlebars
import js.knockout
import os.path


def render_template(library, inner):
    filename = os.path.basename(inner)
    path = os.path.join(library.path, filename)
    with open(path) as f:
        inner = f.read()
    return '<script type="text/html" id="{}">{}</script>'.format(
        os.path.splitext(filename)[0], inner)


library = fanstatic.Library('gocept.jsform', 'resources')


def template_renderer(inner):
    return render_template(library, inner)


ko_mapping = fanstatic.Resource(
    library, 'ko.mapping.js', minified='ko.mapping.min.js',
    depends=[js.knockout.knockout])

helpers = fanstatic.Resource(
    library, 'helpers.js', minified='helpers.min.js',
    depends=[js.jquery.jquery, ko_mapping])


form_template = fanstatic.Resource(
    library, 'gocept_jsform_templates_form.pt', renderer=template_renderer)

string_template = fanstatic.Resource(
    library, 'gocept_jsform_templates_string.pt', renderer=template_renderer)

text_template = fanstatic.Resource(
    library, 'gocept_jsform_templates_text.pt', renderer=template_renderer)

object_template = fanstatic.Resource(
    library, 'gocept_jsform_templates_object.pt', renderer=template_renderer)

boolean_template = fanstatic.Resource(
    library, 'gocept_jsform_templates_boolean.pt', renderer=template_renderer)

multiselect_template = fanstatic.Resource(
    library, 'gocept_jsform_templates_multiselect.pt',
    renderer=template_renderer)

wrapper_template = fanstatic.Resource(
    library, 'gocept_jsform_templates_field_wrapper.pt',
    renderer=template_renderer)

templates = fanstatic.Group([
    form_template, string_template, text_template,
    object_template, boolean_template,
    multiselect_template, wrapper_template])

jsform = fanstatic.Resource(
    library, 'jsform.js', minified='jsform.min.js',
    depends=[helpers, js.handlebars.handlebars, templates,
             js.classy.classy])



import glob
import gocept.jslint
import gocept.testing.mtime
import os
import pkg_resources
import unittest


RESOURCES_DIR = pkg_resources.resource_filename('gocept.jsform', 'resources')
MAKEFILE_DIR = os.getcwd()


class TestMinifiedJSFiles(unittest.TestCase, gocept.testing.mtime.Newer):

    source_ext = '.js'
    target_ext = '.min.js'
    message = '\nRun `make` in %s to fix this.' % MAKEFILE_DIR
    delta = 7  # time delta for jenkins needs to be higher than default.

    def test_minified_js_files_are_younger_than_non_minified_ones(self):
        self.check_files(RESOURCES_DIR)


class TestJSLint(gocept.jslint.TestCase):

    jshint_command = os.environ.get('JSHINT_COMMAND', '/bin/true')
    include = ['gocept.jsform:resources']
    exclude = (['ko.mapping.js', 'json-template.js'] +
               [os.path.basename(x) for x in glob.glob(
                pkg_resources.resource_filename(
                    'gocept.jsform', 'resources/*.min.js'))
                ])



# Copyright (c) 2013 gocept gmbh & co. kg
# See also LICENSE.txt

# This should be only one line. If it must be multi-line, indent the second
# line onwards to keep the PKG-INFO file format intact.
"""Next generation forms in javascript
"""

from setuptools import setup, find_packages


setup(
    name='gocept.jsform',
    version='2.0.1',

    install_requires=[
        'fanstatic>=1.0a2',
        'js.classy',
        'js.jquery',
        'js.handlebars',
        'js.knockout>=3.1.0',
        'cssmin',
        'setuptools',
    ],

    extras_require={
        'test': [
            'gocept.jasmine>=0.3',
            'gocept.jslint',
            'gocept.testing',
        ],
    },

    entry_points={
        'console_scripts': [
            # 'binary-name = gocept.jsform.module:function'
        ],
        'fanstatic.libraries': [
            'gocept.jsform = gocept.jsform.resource:library',
        ],
    },

    author=('Sebastian Wehrmann <sw@gocept.com>, '
            'Maik Derstappen <md@derico.de>'),
    author_email='sw@gocept.com',
    license='ZPL 2.1',
    url='https://bitbucket.org/gocept/gocept.jsform/',

    keywords='form javascript jquery client',
    classifiers="""\
License :: OSI Approved :: Zope Public License
Programming Language :: Python
Programming Language :: Python :: 2
Programming Language :: Python :: 2.6
Programming Language :: Python :: 2.7
Programming Language :: Python :: 2 :: Only
"""[:-1].split('\n'),
    description=__doc__.strip(),
    long_description='\n\n'.join(open(name).read() for name in (
        'src/gocept/jsform/resources/README.md',
        'README.txt',
        'HACKING.txt',
        'CHANGES.txt',
    )),

    namespace_packages=['gocept'],
    packages=find_packages('src'),
    package_dir={'': 'src'},
    include_package_data=True,
    zip_safe=False,
)
